@@ -119,9 +119,8 @@ gbTarget.prototype.initByXML = function(x){
 
 gbTarget.prototype.updateByParamStr = function(paramStr)
 {
-	paramStr = decodeURIComponent(paramStr);
 	var params = paramStr.split("_");
-	this.coord = params[0];
+	this.coord = decodeURIComponent(params[0]);
 	this.position = new gbPosition(
 			params[1],
 			parseFloat(params[2]),
@@ -134,7 +133,7 @@ gbTarget.prototype.updateByParamStr = function(paramStr)
 
 gbTarget.prototype.toQuery = function()
 {
-	return "" + this.coord + "_" + this.position.toQuery();
+	return "" + encodeURIComponent(this.coord) + "_" + this.position.toQuery();
 }
 
 function gbObj()
@@ -1693,9 +1692,7 @@ gbApp.prototype.initByCookie = function()
 
 gbApp.prototype.execTrackBack = function()
 {
-	trace("gbApp.prototype.execTrackBack");
 	var ua = navigator.userAgent.toUpperCase();
-	trace("gbApp.prototype.execTrackBack ua="+ua);
 //	if(ua.match(/MSIE/) && ua.match(/WINDOWS/)){
 //	if(!ua.match(/SAFARI/)){
 		document.location = this.cgiPath.replace("gbgate\.cgi", "trackback.cgi") + "?param="+encodeURIComponent(this.getCurrentParams());
@@ -1704,11 +1701,8 @@ gbApp.prototype.execTrackBack = function()
 
 gbApp.prototype.getTrackBackText = function()
 {
-	trace("gbApp.prototype.getTrackBackText");
 	var path = this.cgiPath.replace("gbgate\.cgi", "getgburl.cgi");
-	trace("gbApp.prototype.getTrackBackText path="+path);
-	var ret = '<trackback>' + doGetText(path) + '?' + this.getCurrentParams() + '</trackback>';
-	trace("gbApp.prototype.getTrackBackText ret="+ret);
+	var ret = '<trackback>' + doGetText(path) + '?' + escapeForXML(this.getCurrentParams()) + '</trackback>';
 	return ret;
 }
 
@@ -2043,7 +2037,7 @@ gbImageLoader.prototype.isActive = function()
 gbImageLoader.prototype.start = function()
 {
 	this.setStatus(gbImageLoader.LOADING_RSS);
-// trace("get rss request query="+this.query);
+	trace("get rss request query="+this.query);
 	this.reqObj = doAsyncRequest(this.getApp().getCgiPath()+"?"+this.query, {obj:this, method:"onLoadRSS", args:""});
 }
 
@@ -2079,7 +2073,7 @@ gbImageLoader.prototype.onLoadRSS = function(is_success, req, userArg)
 	}
 	
 	// trace("gbImageLoader.onLoadRSS responseText.length="+req.responseText.length);
-	// trace("RESPONSE RSS FILE ="+req.responseText);
+	trace("RESPONSE RSS FILE ="+req.responseText);
 	
 	var x = req.responseXML;
 	if(x.parsed!=undefined && x.parsed==false){
